import { DeclareConstructor } from "dojo/_base/declare";

interface Destroyable {
    _destroyed?: true;

    /**
     * Destroy this class, releasing any resources registered via own().
     */
    destroy(preserveDom?: boolean): void;

    /**
     * Track specified handles and remove/destroy them when this instance is destroyed, unless they were
     * already removed/destroyed manually.
     */
    own(...args: any[]): any[];
}

/**
	 * Mixin to track handles and release them when instance is destroyed.
	 */
interface DestroyableConstructor extends DeclareConstructor<Destroyable> { }

declare const Destroyable: DestroyableConstructor;
export = Destroyable;
